@@ -131,7 +131,7 @@ def unescape(text):
     def replchar(m):
         num = m.group(1)
         return unichar(int(num))
-    out = re.sub(u"&#(\d+);", replchar, out)
+    out = re.sub(u"&#(\\d+);", replchar, out)
     return out
 
 
@@ -446,7 +446,7 @@ def _scrape_strip_cruft(html, plain_text_out=False):
     html = html.replace('\r', '\n')  # Normalize EOL.
     html = re.sub(r' +', ' ', html)  # Whitespaces collapse.
     html = BREAK_RE.sub('\n', html)  # <br> eats up surrounding '\n'.
-    html = re.sub(r'<(script).*?</\1>(?s)', '', html)  # Strip script tags.
+    html = re.sub(r'(?s)<(script).*?</\1>', '', html)  # Strip script tags.
 
     if plain_text_out:  # Strip remaining HTML tags
         html = COMMENT_RE.sub('', html)
@@ -537,12 +537,12 @@ class Google(Backend):
         """
         text = re.sub(r"[-'_\s]", '_', text)
         text = re.sub(r"_+", '_', text).strip('_')
-        pat = "([^,\(]*)\((.*?)\)"  # Remove content within parentheses
-        text = re.sub(pat, '\g<1>', text).strip()
+        pat = r"([^,\(]*)\((.*?)\)"  # Remove content within parentheses
+        text = re.sub(pat, r'\g<1>', text).strip()
         try:
             text = unicodedata.normalize('NFKD', text).encode('ascii',
                                                               'ignore')
-            text = six.text_type(re.sub('[-\s]+', ' ', text.decode('utf-8')))
+            text = six.text_type(re.sub(r'[-\s]+', ' ', text.decode('utf-8')))
         except UnicodeDecodeError:
             self._log.exception(u"Failing to normalize '{0}'", text)
         return text
